Loads the global class list from the SQLite database (shared with ClassiPyR). Returns NULL if the database does not exist or has no class list entries.
Loads the global class list from the SQLite database (shared with ClassiPyR). Returns NULL if the database does not exist or has no class list entries.