HAB species are marked with a red asterisk (*) on the y-axis labels.
Arguments
- wide_summary
Wide-format data from
create_wide_summary().- taxa_lookup
Optional taxa lookup table with
HABcolumn. If provided, HAB species are annotated with a red asterisk on the y-axis.- title
Plot title.
- sample_counts
Optional named integer vector mapping station_date column names to number of samples. If provided,
n = Xis appended to each x-axis label.