Plots per-sample image counts along the cruise track, showing spatial distribution of cell abundance as measured by the IFCB.
Arguments
- image_counts
Data frame from
fetch_image_counts()with columns: latitude, longitude, n_images.
Plots per-sample image counts along the cruise track, showing spatial distribution of cell abundance as measured by the IFCB.
Data frame from fetch_image_counts() with
columns: latitude, longitude, n_images.